from .main import setAccount,sendEmail

__all__=[
    'setAccount',
    'sendEmail'
]


__version__='0.9.1'
__license__='GPL-2.0 License'
__author__='Tiancheng Jiao'
__url__='https://github.com/jtc1246/outlook'
__author_email__='jtc1246@outlook.com'
__description__='A simple email sender for Outlook'


import time,json,urllib3

def getTime():
    t = time.time()
    t = int(1000 * t)
    return t


def toJson(Text):
    text=Text
    i=0
    while text[0]==' ' or text[0]=='\n':
        text=text[1:]
    if text[0]=='[':
        text='{"1":'+text+'}'
        i=1
    text=json.loads(text,strict=False)
    if i==1:
        text=text['1']
    return text


def testInternet():
    http1=urllib3.PoolManager()
    try:
        r=http1.request("GET",'https://apple.com',timeout=2,retries=False)
    except:
        return -1
    return 0


